package org.apache.bcel.classfile;

import java.io.DataInput;
import java.io.DataOutputStream;
import java.io.IOException;
import java.util.Iterator;
import java.util.stream.Stream;

/* loaded from: org_apache_bcel_classfile.jar:org/apache/bcel/classfile/BootstrapMethods.class */
public class BootstrapMethods extends Attribute implements Iterable<BootstrapMethod> {
    private BootstrapMethod[] bootstrapMethods;

    public BootstrapMethods(BootstrapMethods c) {
        this(c.getNameIndex(), c.getLength(), c.getBootstrapMethods(), c.getConstantPool());
    }

    public BootstrapMethods(int nameIndex, int length, BootstrapMethod[] bootstrapMethods, ConstantPool constantPool) {
        super((byte) 20, nameIndex, length, constantPool);
        this.bootstrapMethods = bootstrapMethods;
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public BootstrapMethods(int nameIndex, int length, DataInput input, ConstantPool constantPool) throws IOException {
        this(nameIndex, length, (BootstrapMethod[]) null, constantPool);
        int numBootstrapMethods = input.readUnsignedShort();
        this.bootstrapMethods = new BootstrapMethod[numBootstrapMethods];
        for (int i = 0; i < numBootstrapMethods; i++) {
            this.bootstrapMethods[i] = new BootstrapMethod(input);
        }
    }

    @Override // org.apache.bcel.classfile.Attribute, org.apache.bcel.classfile.Node
    public void accept(Visitor v) {
        v.visitBootstrapMethods(this);
    }

    @Override // org.apache.bcel.classfile.Attribute
    public BootstrapMethods copy(ConstantPool constantPool) {
        BootstrapMethods c = (BootstrapMethods) clone();
        c.bootstrapMethods = new BootstrapMethod[this.bootstrapMethods.length];
        for (int i = 0; i < this.bootstrapMethods.length; i++) {
            c.bootstrapMethods[i] = this.bootstrapMethods[i].copy();
        }
        c.setConstantPool(constantPool);
        return c;
    }

    @Override // org.apache.bcel.classfile.Attribute
    public final void dump(DataOutputStream file) throws IOException {
        super.dump(file);
        file.writeShort(this.bootstrapMethods.length);
        for (BootstrapMethod bootstrapMethod : this.bootstrapMethods) {
            bootstrapMethod.dump(file);
        }
    }

    public final BootstrapMethod[] getBootstrapMethods() {
        return this.bootstrapMethods;
    }

    @Override // java.lang.Iterable
    public Iterator<BootstrapMethod> iterator() {
        return Stream.of((Object[]) this.bootstrapMethods).iterator();
    }

    public final void setBootstrapMethods(BootstrapMethod[] bootstrapMethods) {
        this.bootstrapMethods = bootstrapMethods;
    }

    @Override // org.apache.bcel.classfile.Attribute
    public final String toString() {
        StringBuilder buf = new StringBuilder();
        buf.append("BootstrapMethods(");
        buf.append(this.bootstrapMethods.length);
        buf.append("):");
        for (int i = 0; i < this.bootstrapMethods.length; i++) {
            buf.append("\n");
            int start = buf.length();
            buf.append("  ").append(i).append(": ");
            int indentCount = buf.length() - start;
            String[] lines = this.bootstrapMethods[i].toString(super.getConstantPool()).split("\\r?\\n");
            buf.append(lines[0]);
            for (int j = 1; j < lines.length; j++) {
                buf.append("\n").append((CharSequence) "          ", 0, indentCount).append(lines[j]);
            }
        }
        return buf.toString();
    }
}
